@@ -58,9 +58,6 @@
 
 #define HIDE_WINDOW_CURSOR_TIMEOUT 3.0f
 
-#define PAROLE_GST_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE((o), PAROLE_TYPE_GST, ParoleGstPrivate))
-
 static void       parole_gst_play_file_internal(ParoleGst *gst);
 
 static void       parole_gst_change_state(ParoleGst *gst,
@@ -165,7 +162,7 @@ static gpointer parole_gst_object = NULL;
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE(ParoleGst, parole_gst, GTK_TYPE_WIDGET)
+G_DEFINE_TYPE_WITH_PRIVATE(ParoleGst, parole_gst, GTK_TYPE_WIDGET)
 
 static void
 parole_gst_finalize(GObject *object) {
@@ -1257,6 +1254,25 @@ parole_gst_application_message(ParoleGst *gst, GstMessage *msg) {
     }
 }
 
+static void
+parole_gst_missing_codec_helper_dialog(void) {
+    GtkMessageDialog *dialog;
+
+    dialog = GTK_MESSAGE_DIALOG(gtk_message_dialog_new_with_markup(
+                            NULL,
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING,
+                            GTK_BUTTONS_OK,
+                            "<b><big>%s</big></b>",
+                            _("Unable to install missing codecs.")));
+
+    gtk_message_dialog_format_secondary_markup(dialog,
+                                               _("No available plugin installer was found."));
+
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
 /**
  * parole_gst_install_plugins_result_func:
  * @result    : %GST_INSTALL_PLUGINS_SUCCESS (0) if successful
@@ -1413,6 +1429,8 @@ parole_gst_bus_event(GstBus *bus, GstMessage *msg, gpointer data) {
         break;
     case GST_MESSAGE_ELEMENT:
         if (gst_is_missing_plugin_message(msg)) {
+            GstInstallPluginsReturn result;
+
             g_debug("Missing plugin\n");
             parole_gst_stop(gst);
             dialog = parole_gst_missing_codec_dialog(gst, msg);
@@ -1430,9 +1448,13 @@ parole_gst_bus_event(GstBus *bus, GstMessage *msg, gpointer data) {
                 }
 #endif /* GDK_WINDOWING_X11 */
 
-                 gst_install_plugins_async((const gchar * const *) details, ctx,
-                                           parole_gst_install_plugins_result_func, gst);
-                 gst_install_plugins_context_free(ctx);
+                result = gst_install_plugins_async((const gchar * const *) details,
+                    ctx, parole_gst_install_plugins_result_func, gst);
+
+                if (result == GST_INSTALL_PLUGINS_HELPER_MISSING)
+                    parole_gst_missing_codec_helper_dialog();
+
+                gst_install_plugins_context_free(ctx);
             } else if ( (response == GTK_RESPONSE_REJECT) || (response == GTK_RESPONSE_OK) ) {
                 gtk_widget_destroy(GTK_WIDGET(dialog));
             }
@@ -2099,13 +2121,11 @@ parole_gst_class_init(ParoleGstClass *klass) {
                                             NULL, NULL,
                                             TRUE,
                                             G_PARAM_READWRITE));
-
-    g_type_class_add_private (klass, sizeof (ParoleGstPrivate));
 }
 
 static void
 parole_gst_init(ParoleGst *gst) {
-    gst->priv = PAROLE_GST_GET_PRIVATE(gst);
+    gst->priv = parole_gst_get_instance_private(gst);
 
     gst->priv->state = GST_STATE_VOID_PENDING;
     gst->priv->target = GST_STATE_VOID_PENDING;
