@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_BUILDER_H
-#define __PAROLE_BUILDER_H
+#ifndef SRC_PAROLE_BUILDER_H_
+#define SRC_PAROLE_BUILDER_H_
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -35,4 +35,4 @@ GtkBuilder      *parole_builder_new_from_string     (const gchar *ui,
 
 G_END_DECLS
 
-#endif /* __PAROLE_BUILDER_H */
+#endif /* SRC_PAROLE_BUILDER_H_ */
